Shrub - Better Experience of Developping Deep Learning Systems
==============================================================

![Build and Test](https://github.com/jackwish/shrub/workflows/Build%20and%20Test/badge.svg)
![Sanity](https://github.com/jackwish/shrub/workflows/Sanity/badge.svg)


Have you been tired of writing similar testing code for your deep learning system?
Have you asked yourself why I am repeating test example one after another?
**Shrub** is here for you, a collection of utilities that aims to
improve your experience of developping deep learning system.

Create tensors, manipulate layouts and data types of them;
use same model description with layout-aware for different systems;
manage data for numerous frameworks, or engines, and validate them;
and son on.


## Usage

Install via `pip install shrub`. *A lot dependency will be installed too, take care of that.*

`shrub.network` is where the `Tensor` and `Model` locates.
Others are basically runners, try and hack them!
[API documents](https://jackwish.net/shrub/docs)


## Contributing

Contributions are welcome!

Bring any greate idea here, bring any barrier here, bring the code here,
to help engineers and reseachers who are just like yourself.
And they will certainly help you back.


## License

Apache License Version 2.0
